# Changelog

## 0.1.0-alpha.1 (2025-07-06)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/bluehive-health/bluehive-sdk-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([90448d7](https://github.com/bluehive-health/bluehive-sdk-python/commit/90448d76356b411bb678274c923ebf0d5d904218))


### Chores

* configure new SDK language ([d15c2c6](https://github.com/bluehive-health/bluehive-sdk-python/commit/d15c2c680ba6c46102b5b37fb3d9f31a66e5ba8d))
* update SDK settings ([4e5fa24](https://github.com/bluehive-health/bluehive-sdk-python/commit/4e5fa2407f9fcf01e7c25d040b4656246cb8d492))
* update SDK settings ([a9c06ff](https://github.com/bluehive-health/bluehive-sdk-python/commit/a9c06ff66ca3d06d5c6d1dc35458fbd387a5b7bc))
